@@ -17,7 +17,7 @@ fitmzsm <- function(x, trunc, start.value, upper = length(x), ...){
     {
       LL <- function(J, theta) -sum(dtrunc("mzsm", x=x, coef = list(J = J, theta = theta), trunc = trunc, log = TRUE))
     }  
-  result <- do.call("mle2", c(list(LL, start = list(theta = thetahat), fixed=list(J=sum(x)), data = list(x = x), method ="Brent", lower=0.001, upper=upper), ...))
+  result <- do.call("mle2", c(list(LL, start = list(theta = thetahat), fixed=list(J=sum(x)), data = list(x = x), method ="Brent", lower=0.001, upper=upper), dots))
   if(abs(as.numeric(result@coef) - upper) < 0.0000001) warning("mle equal to upper bound provided. \n Try value for the 'upper' arguent")
   new("fitsad", result, sad="mzsm", distr = "D", trunc = ifelse(missing(trunc), NaN, trunc)) 
 }
