@@ -15,7 +15,7 @@ fitpareto <- function(x, trunc, start.value, upper = 20, ...){
                                              coef = list(shape = shape, scale = scale), trunc = trunc, log = TRUE))
   }  
   result <- do.call("mle2", c(list(LL, start = list(shape = alpha, scale=min(x)), fixed=list(scale=min(x)),
-                 data = list(x = x), method = "Brent", lower = 0, upper = upper), ...))
+                 data = list(x = x), method = "Brent", lower = 0, upper = upper), dots))
   if(abs(as.numeric(result@coef) - upper) < 0.001) 
     warning("mle equal to upper bound provided. \n Try value for the 'upper' argument")
   new("fitsad", result, sad="pareto", distr = "C", trunc = ifelse(missing(trunc), NaN, trunc)) 
